@@ -930,13 +930,28 @@ BranchItem* MapEditor::getBranchBelow (BranchItem *selbi)
     return NULL;
 }
 
-BranchItem* MapEditor::getLeftBranch (BranchItem *bi)
+BranchItem* MapEditor::getLeftBranch (BranchItem *bi)  
 {
     if (bi)
     {
 	if (bi->depth()==0)
+	{ 
 	    // Special case: use alternative selection index
-	    return bi->getLastSelectedBranchAlt();  
+	    BranchItem *newbi=bi->getLastSelectedBranchAlt();  
+	    if (!newbi)
+	    {
+		BranchObj *bo;
+		// Try to find a mainbranch left of center
+		for (int i=0; i<bi->branchCount(); i++)
+		{
+		    newbi=bi->getBranchNum(i);
+		    bo=newbi->getBranchObj();
+		    if (bo && bo->getOrientation()==LinkableMapObj::LeftOfCenter)
+			break;
+		}
+	    }
+	    return newbi;
+	}
 	if (bi->getBranchObj()->getOrientation()==LinkableMapObj::RightOfCenter)    
 	    // right of center
 	    return (BranchItem*)(bi->parent());
@@ -952,7 +967,24 @@ BranchItem* MapEditor::getRightBranch(BranchItem *bi)
 {
     if (bi)
     {
-	if (bi->depth()==0) return bi->getLastSelectedBranch();	
+	if (bi->depth()==0)
+	{
+	    // Special case: use alternative selection index
+	    BranchItem *newbi=bi->getLastSelectedBranch();  
+	    if (!newbi)
+	    {
+		BranchObj *bo;
+		// Try to find a mainbranch right of center
+		for (int i=0; i<bi->branchCount(); i++)
+		{
+		    newbi=bi->getBranchNum(i);
+		    bo=newbi->getBranchObj();
+		    if (bo && bo->getOrientation()==LinkableMapObj::RightOfCenter)
+			qDebug()<<"BI found right: "<<newbi->getHeading();
+		}
+	    }
+	    return newbi;
+	}
 	if (bi->getBranchObj()->getOrientation()==LinkableMapObj::LeftOfCenter)	
 	    // left of center
 	    return (BranchItem*)(bi->parent());
@@ -1049,6 +1081,7 @@ void MapEditor::editHeadingFinished()
     model->setHeading (s);
     model->setSelectionBlocked(false);
     delete (lineEdit);
+    lineEdit=NULL;
 
     animateScrollBars();
 
@@ -1185,7 +1218,20 @@ void MapEditor::mousePressEvent(QMouseEvent* e)
     LinkableMapObj* lmo=NULL;
     if (ti) lmo=((MapItem*)ti)->getLMO();
     
-    // Select the clicked object
+    // Now check PickColor modifier (before selecting object!) 
+    if (ti && (e->modifiers() & Qt::ShiftModifier) &&
+	mainWindow->getModMode()==Main::ModModeColor)
+    {
+	setState (PickingColor);
+	mainWindow->setCurrentColor (ti->getHeadingColor() );
+	if ((e->modifiers() & Qt::ShiftModifier) && (e->modifiers() & Qt::ControlModifier) )
+	    model->colorBranch(ti->getHeadingColor());
+	else    
+	    model->colorSubtree(ti->getHeadingColor());
+	return;
+    }	
+
+    // Select the clicked object 
     if (e->modifiers() & Qt::ControlModifier)
 	model->selectToggle (ti);
     else
@@ -1284,14 +1330,6 @@ void MapEditor::mousePressEvent(QMouseEvent* e)
 	tmpLink->updateLink();
 	return;
     }
-    // Now check PickColor modifier
-    if (ti && (e->modifiers() & Qt::ShiftModifier) &&
-	mainWindow->getModMode()==Main::ModModeColor)
-    {
-	setState (PickingColor);
-	mainWindow->setCurrentColor (ti->getHeadingColor() );
-	return;
-    }	
 
     // Start moving around
     if (lmo) 
@@ -2001,7 +2039,11 @@ void MapEditor::updateSelection(QItemSelection nsel,QItemSelection dsel)
 	sp->setBrush (selectionColor);	
 	sp->setParentItem (mo); 
 	sp->setZValue (dZ_SELBOX);
+
+	// Reposition also LineEdit for heading during animation
+	if (lineEdit) lineEdit->move (mo->getAbsPos().toPoint() );
     }
+
     scene()->update();  
 }
 
